@@ -3,11 +3,12 @@ use Carp;
 use Moose;
 with 'I22r::Translate::Filter';
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 sub apply {
     my ($self, $req, $key) = @_;
-    my $otext = my $_ = $req->text->{$key};
+    local $_;
+    my $otext = $_ = $req->text->{$key};
     my $keymap = $self->{map}{$key} //= {};
 
     my $html_transform_count = 0;
@@ -60,7 +61,8 @@ sub unapply {
 }
 
 sub _unapply {
-    my ($self, $req, $key, $_) = @_;
+    my ($self, $req, $key, $topic) = @_;
+    local $_ = $topic;
     my $keymap = $self->{map}{$key};
     return $_ unless $keymap->{__keys__};
     foreach my $enc (reverse @{$keymap->{__keys__}}) {
