@@ -3,7 +3,7 @@ use Carp;
 use Moose;
 with 'I22r::Translate::Filter';
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 our $DOUBLE_BRACES_WRAP_LITERAL = 1;
 our $DOUBLE_BRACES_WRAP_PARAMETER_LITERAL = 1;
@@ -12,7 +12,7 @@ our $HTML_ENTITIES_ARE_LITERAL = 1;
 sub apply {
     my ($self, $req, $key) = @_;
 
-    my $_ = $req->text->{$key};
+    local $_ = $req->text->{$key};
     my $keymap = $self->{map}{$key} //= { __keys__ => [] };
 
     if ($DOUBLE_BRACES_WRAP_PARAMETER_LITERAL) {
@@ -58,7 +58,8 @@ sub unapply {
 }
 
 sub _unapply {
-    my ($self, $req, $key, $_, $apply_m2) = @_;
+    my ($self, $req, $key, $topic, $apply_m2) = @_;
+    local $_ = $topic;
 
     my $keymap = $self->{map}{$key};
 
