@@ -6,7 +6,7 @@ use Carp;
 use Data::Dumper;
 with 'I22r::Translate::Backend';
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 {
     # code from REST::Google and REST::Google::Translate2 packages.
@@ -117,8 +117,8 @@ sub can_translate {
     if ($lang1 eq $lang2) {
 	return 1;
     }
-    return unless $lang1 ~~ [ @google_languages, values %remap ];
-    return unless $lang2 ~~ [ @google_languages, values %remap ];
+    my $langs = join(" ", @google_languages, values %remap);
+    return -1 unless " $langs " =~ / $lang1 / && " $langs " =~ / $lang2 /;
 
     if ($lang1 =~ /zh/ && $lang2 =~ /zh/) {
 	# assume translation between zh-CN and zh-TW is easy
